@@ -57,9 +57,9 @@ altmin <-
       epsilonmat <- matrix(cov%*% epsilon, nrow=n)
       armijo.step <- 1e-3
       ref.obj <-
-        sum(-Y * (mu+alpmat + betmat + epsmat + theta) + exp(mu+alpmat + betmat +
-                                                             epsmat + theta),
-            na.rm = T) / m + lambda1 * sum(d.tmp) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta)))
+        sum((-Y * (mu+alpmat + betmat + epsmat + theta) + exp(mu+alpmat + betmat +
+                                                                epsmat + theta)),
+            na.rm = T) / (m) + lambda1 * sum(d.tmp) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta)))
       while(flag){
         #print(step)
         maineff <- sign(c(alpha.tmp, beta.tmp, epsilon.tmp)-step*grad)*pmax(abs(c(alpha.tmp, beta.tmp, epsilon.tmp)-step*grad)-step*lambda2, 0)
@@ -70,22 +70,24 @@ altmin <-
         betmat <- matrix(rep(beta, each=n), nrow=n)
         epsmat <- matrix(cov%*% epsilon, nrow=n)
         diff <-
-          sum(-Y * (mu + alpmat + betmat + epsmat + theta) + exp(mu + alpmat + betmat +
-                                                                 epsmat + theta),
-              na.rm = T) / m + lambda1 * sum(d.tmp) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta))) - ref.obj
+          sum((-Y * (mu + alpmat + betmat + epsmat + theta) + exp(mu + alpmat + betmat +
+                                                                    epsmat + theta)),
+              na.rm = T) / (m) + lambda1 * sum(d.tmp) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta))) - ref.obj
         flag <- diff > thresh * abs(ref.obj)
         step <- 0.5*step
       }
-      grad_theta <- (-Y2 + exp(mu + alpmat + betmat + epsmat + theta)) / m
+      X <- mu + alpmat + betmat + epsmat + theta
+      grad_theta <- (-Y2 + exp(mu + alpmat + betmat + epsmat + theta)) /m
       grad_theta <- sweep(grad_theta, 2, colMeans(grad_theta))
       grad_theta <- sweep(grad_theta, 1, rowMeans(grad_theta))
+
       flag <- TRUE
       step <- 1
       armijo.step <- 1e-2
       ref.obj <-
-        sum(-Y * (mu + alpmat + betmat + epsmat + theta) + exp(mu + alpmat + betmat +
-                                                               epsmat + theta),
-            na.rm = T) / m + lambda1 * sum(d.tmp) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta)))
+        sum((-Y * (mu + alpmat + betmat + epsmat + theta) + exp(mu + alpmat + betmat +
+                                                                  epsmat + theta)),
+            na.rm = T) / (m) + lambda1 * sum(d.tmp) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta)))
       while (flag) {
         #print(step)
         svd_theta <-
@@ -106,15 +108,15 @@ altmin <-
           theta2 <- u %*% diag(d) %*% t(v)
         }
         diff <-
-          sum(-Y * (mu + alpmat + betmat + epsmat + theta2) + exp(mu + alpmat + betmat +
-                                                                  epsmat + theta2),
-              na.rm = T) / m + lambda1 * sum(d) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta)))- ref.obj
+          sum((-Y* (mu + alpmat + betmat + epsmat + theta2) + exp(mu + alpmat + betmat +
+                                                                    epsmat + theta2)),
+              na.rm = T) / (m) + lambda1 * sum(d) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta)))- ref.obj
         flag <- diff > thresh * abs(ref.obj)
         step <- 0.5 * step
       }
       theta <- theta2
       X <- mu + alpmat + betmat + epsmat + theta
-      objective = c(objective,-sum(Y * X - Omega * exp(X), na.rm = T) / m + lambda1 *
+      objective = c(objective,-sum((Y * X - Omega * exp(X)), na.rm = T) /m + lambda1 *
                       sum(d) + sum(lambda2 * c(abs(epsilon),abs(alpha), abs(beta))))
       if(count==1){
         error <- 1
